<?php
if (!function_exists('sportsx_get_option')) :
    /**
     * Get customizer value by key.
     *
     * @param string $key Option key.
     * @return mixed Option value.
     * @since 1.0.0
     *
     */
    function sportsx_get_option($key)
    {
        $key_value = '';
        if (!$key) {
            return $key_value;
        }
        $default_values = sportsx_get_all_customizer_default_values();
        $customizer_values = get_theme_mod('sportsx_options');
        $customizer_values = wp_parse_args($customizer_values, $default_values);

        $key_value = (isset($customizer_values[$key])) ? $customizer_values[$key] : '';
        return $key_value;
    }
endif;

if ( ! function_exists( 'sportsx_get_archive_layouts' ) ) :
	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_get_archive_layouts() {
		$options = apply_filters(
			'sportsx_get_archive_layouts',
			array(
				'archive_style_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-1.webp',
					'label' => esc_html__( 'Archive List View', 'sportsx' ),
				),
				'archive_style_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-2.webp',
					'label' => esc_html__( 'Archive Grid View', 'sportsx' ),
				),
				'archive_style_3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-3.webp',
					'label' => esc_html__( 'Archive Alternate Grid View', 'sportsx' ),
				),
			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'sportsx_get_date_formats' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_get_date_formats() {
		$options = apply_filters(
			'sportsx_archive_date_format',
			array(
				'classic'   => __( 'Classic', 'sportsx' ),
				'time_ago' => __( 'Time Ago', 'sportsx' ),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'sportsx_line_limit_choices' ) ) :
	/**
	 * Returns title limit options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_line_limit_choices() {
		$options = apply_filters(
			'sportsx_title_limit_options',
			array(
				''              => __( '&mdash; No Limit &mdash;', 'sportsx' ),
				'limit-line-1' => __( '1 Line', 'sportsx' ),
				'limit-line-2' => __( '2 Lines', 'sportsx' ),
				'limit-line-3' => __( '3 Lines', 'sportsx' ),
				'limit-line-4' => __( '4 Lines', 'sportsx' ),
				'limit-line-5' => __( '5 Lines', 'sportsx' ),
			)
		);
		return $options;
	}
endif;
if ( ! function_exists( 'sportsx_archive_category_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_archive_category_style() {
		$options = apply_filters(
			'sportsx_archive_category_style',
			array(
				'archive_cat_style_1'   => __( 'Category Style 1', 'sportsx' ),
				'archive_cat_style_2'   => __( 'Category Style 2', 'sportsx' ),
				'archive_cat_style_3'   => __( 'Category Style 3', 'sportsx' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'sportsx_archive_read_time_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_archive_read_time_style() {
		$options = apply_filters(
			'sportsx_archive_read_time_style',
			array(
				'archive_read_time_style_1'   => __( 'Read Time Style 1', 'sportsx' ),
				'archive_read_time_style_2'   => __( 'Read Time Style 2', 'sportsx' ),
				'archive_read_time_style_3'   => __( 'Read Time Style 3', 'sportsx' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'sportsx_get_header_layout' ) ) :
	/**
	 * Returns header layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_get_header_layout() {
		$options = apply_filters(
			'sportsx_get_header_layout',
			array(
				'header_style_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/header-1.webp',
					'label' => esc_html__( 'Header Style 1', 'sportsx' ),
				),
				'header_style_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/header-2.webp',
					'label' => esc_html__( 'Header Style 2', 'sportsx' ),
				),
        'header_style_3' => array(
            'url'   => get_template_directory_uri() . '/assets/images/header-3.webp',
            'label' => esc_html__( 'Header Style 3', 'sportsx' ),
        ),
        'header_style_4' => array(
            'url'   => get_template_directory_uri() . '/assets/images/header-4.webp',
            'label' => esc_html__( 'Header Style 4', 'sportsx' ),
        ),
			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'sportsx_social_menu_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_social_menu_style() {
		$options = apply_filters(
			'sportsx_social_menu_style',
			array(
				'has-brand-background'   => __( 'Has Brand Background', 'sportsx' ),
				'has-brand-color'   => __( 'Has Brand Color', 'sportsx' ),
				'none'   => __( 'None', 'sportsx' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'sportsx_pagination_style_choice' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_pagination_style_choice() {
		$options = apply_filters(
			'sportsx_pagination_style_choice',
			array(
				'pagination_none'   => __( 'None', 'sportsx' ),
				'pagination_numeric'   => __( 'Numeric', 'sportsx' ),
				'pagination_default'   => __( 'Default(New/Old Post)', 'sportsx' ),
				'pagination_ajax_on_scroll'   => __( 'Load More On Scroll', 'sportsx' ),
				'pagination_ajax_on_click'   => __( 'Load More On Click', 'sportsx' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'sportsx_category_color' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_category_color() {
		$options = apply_filters(
			'sportsx_category_color',
			array(
				'none'   => __( 'None', 'sportsx' ),
				'has-background'   => __( 'Has background', 'sportsx' ),
				'has-text-color'   => __( 'Has text color', 'sportsx' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'sportsx_get_footer_layouts' ) ) :
	/**
	 * Returns footer layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_get_footer_layouts() {
		$options = apply_filters(
			'sportsx_footer_layouts',
			array(
				'footer_layout_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-4.webp',
					'label' => esc_html__( 'Four Columns', 'sportsx' ),
				),
				'footer_layout_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-3.webp',
					'label' => esc_html__( 'Three Columns', 'sportsx' ),
				),
				'footer_layout_3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2.webp',
					'label' => esc_html__( 'Two Columns', 'sportsx' ),
				),
				'footer_layout_4' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2-big-left.webp',
					'label' => esc_html__( 'Two Columns Big Left', 'sportsx' ),
				),
				'footer_layout_5' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-3-big-middle.webp',
					'label' => esc_html__( 'Three Columns Big Middle', 'sportsx' ),
				),
				'footer_layout_6' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2-big-right.webp',
					'label' => esc_html__( 'Two Columns Big Right', 'sportsx' ),
				),
				'footer_layout_7' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-1.webp',
					'label' => esc_html__( 'Single Column', 'sportsx' ),
				),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'sportsx_preloader_style_option' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_preloader_style_option() {
		$options = apply_filters(
			'sportsx_preloader_style_option',
			array(
				'style-1'   => __( 'Style - 1', 'sportsx' ),
				'style-2'   => __( 'Style - 2', 'sportsx' ),
				'style-3'   => __( 'Style - 3', 'sportsx' ),
				'style-4'   => __( 'Style - 4', 'sportsx' ),
				'style-5'   => __( 'Style - 5', 'sportsx' ),
				'style-6'   => __( 'Style - 6', 'sportsx' ),
				'style-7'   => __( 'Style - 7', 'sportsx' ),
				'style-8'   => __( 'Style - 8', 'sportsx' ),
				'style-9'   => __( 'Style - 9', 'sportsx' ),
				'style-10'   => __( 'Style - 10', 'sportsx' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'sportsx_get_recommended_post' ) ) :
	/**
	 * Returns recommended layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_get_recommended_post() {
		$options = apply_filters(
			'sportsx_get_recommended_post',
			array(
				'wpi-post-recommendation-1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-1.webp',
					'label' => esc_html__( 'Recommended List View', 'sportsx' ),
				),
				'wpi-post-recommendation-2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-2.webp',
					'label' => esc_html__( 'Recommended Grid View', 'sportsx' ),
				),
				'wpi-post-recommendation-3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-3.webp',
					'label' => esc_html__( 'Recommended Alternate Grid View', 'sportsx' ),
				),
			)
		);
		return $options;
	}
endif;



if ( ! function_exists( 'sportsx_author_meta' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_author_meta() {
		$options = apply_filters(
			'sportsx_author_meta',
			array(
				'with_label'   => __( 'With Label', 'sportsx' ),
				'with_icon'   => __( 'With Icon', 'sportsx' ),
				'with_avatar_image'   => __( 'With Avatar Image', 'sportsx' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'sportsx_date_meta' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_date_meta() {
		$options = apply_filters(
			'sportsx_date_meta',
			array(
				'with_label'   => __( 'With Label', 'sportsx' ),
				'with_icon'   => __( 'With Icon', 'sportsx' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'sportsx_get_sidebar_layouts' ) ) :
	/**
	 * Returns general layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_get_sidebar_layouts() {
		$options = apply_filters(
			'sportsx_sidebar_layouts',
			array(
				'left-sidebar'      => array(
					'url'   => get_template_directory_uri() . '/assets/images/left-sidebar.webp',
					'label' => esc_html__( 'Left Sidebar', 'sportsx' ),
				),
				'right-sidebar'     => array(
					'url'   => get_template_directory_uri() . '/assets/images/right-sidebar.webp',
					'label' => esc_html__( 'Right Sidebar', 'sportsx' ),
				),
				'no-sidebar'        => array(
					'url'   => get_template_directory_uri() . '/assets/images/no-sidebar.webp',
					'label' => esc_html__( 'No Sidebar - Wide', 'sportsx' ),
				),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'sportsx_get_social_links_styles' ) ) :
	/**
	 * Returns social links styles options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function sportsx_get_social_links_styles() {
		$options = apply_filters(
			'sportsx_social_links_styles',
			array(
				'style_1' => __( 'Style 1', 'sportsx' ),
				'style_2' => __( 'Style 2', 'sportsx' ),
				'style_3' => __( 'Style 3', 'sportsx' ),
				'style_4' => __( 'Style 4', 'sportsx' ),
			)
		);
		return $options;
	}
endif;
