<?php
/**
 * All settings related to archive.
 *
 * @package Sportsx
 */
$wp_customize->add_section(
	'archive_options',
	array(
		'title' => esc_html__( 'Archive Options', 'sportsx' ),
		'panel' => 'archive_options_panel',
	)
);

// Archive Layout.
$wp_customize->add_setting(
    'sportsx_options[archive_layout]',
    array(
        'default'           => $sportsx_default['archive_layout'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sportsx_sanitize_radio'
    )
);

$wp_customize->add_control(
    new Sportsx_Custom_Radio_Image_Control(
        $wp_customize,
        'sportsx_options[archive_layout]',
        array(
            'label'         => esc_html__( 'Archive Layout', 'sportsx' ),
            'section'       => 'archive_options',
            'choices'       => sportsx_get_archive_layouts(),
        )
    )
);

$wp_customize->add_setting(
    'sportsx_section_seperator_archive_1',
    array(
        'default'           => '',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field'
    )
);

$wp_customize->add_control(
    new Sportsx_Seperator_Control(
        $wp_customize,
        'sportsx_section_seperator_archive_1',
        array(
            'label'         => esc_html__( 'Archive Meta Options', 'sportsx' ),
            'settings' => 'sportsx_section_seperator_archive_1',
            'section' => 'archive_options',
        )
    )
);


$wp_customize->add_setting(
    'sportsx_options[archive_posts_title_limit]',
    array(
        'default'           => $sportsx_default['archive_posts_title_limit'],
        'sanitize_callback' => 'sportsx_sanitize_select',
    )
);
$wp_customize->add_control(
    'sportsx_options[archive_posts_title_limit]',
    array(
        'label'    => __( 'Title Line Limit', 'sportsx' ),
        'section'  => 'archive_options',
        'type'     => 'select',
        'choices'  => sportsx_line_limit_choices(),
    )
);


$wp_customize->add_setting(
    'sportsx_options[enable_excerpt_on_archive_1]',
    array(
        'default'           => $sportsx_default['enable_excerpt_on_archive_1'],
        'sanitize_callback' => 'sportsx_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'sportsx_options[enable_excerpt_on_archive_1]',
    array(
        'label'    => __( 'Enable Excerpt On Archive', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
        'active_callback' => 'sportsx_is_archive_excerpt_callbac_1',

    )
);



$wp_customize->add_setting(
    'sportsx_options[enable_excerpt_on_archive_2]',
    array(
        'default'           => $sportsx_default['enable_excerpt_on_archive_2'],
        'sanitize_callback' => 'sportsx_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'sportsx_options[enable_excerpt_on_archive_2]',
    array(
        'label'    => __( 'Enable Excerpt On Archive', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
        'active_callback' => 'sportsx_is_archive_excerpt_callbac_2',
        
    )
);

$wp_customize->add_setting(
    'sportsx_options[enable_archive_author_meta]',
    array(
        'default'           => $sportsx_default['enable_archive_author_meta'],
        'sanitize_callback' => 'sportsx_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'sportsx_options[enable_archive_author_meta]',
    array(
        'label'       => esc_html__( 'Show Author Meta', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);

$wp_customize->add_setting(
    'sportsx_options[select_author_meta]',
    array(
        'default'           => $sportsx_default['select_author_meta'],
        'sanitize_callback' => 'sportsx_sanitize_select',
    )
);
$wp_customize->add_control(
    'sportsx_options[select_author_meta]',
    array(
        'label'         => esc_html__( 'Author Meta Display Options', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'select',
        'choices'       => sportsx_author_meta(),
        'active_callback' => 'sportsx_is_archive_author_meta_enabled',


    )
);

$wp_customize->add_setting(
    'sportsx_options[archive_author_meta_title]',
    array(
        'default'           => $sportsx_default['archive_author_meta_title'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'sportsx_options[archive_author_meta_title]',
    array(
        'label'    => __( 'Author Meta Text', 'sportsx' ),
        'section'  => 'archive_options',
        'type'     => 'text',
        'active_callback' => function ( $control ) {
            return (
                sportsx_is_archive_author_meta_enabled( $control )
                &&
                sportsx_archive_author_meta_title( $control )
            );
        },
    )
);

$wp_customize->add_setting(
    'sportsx_options[enable_archive_date_meta]',
    array(
        'default'           => $sportsx_default['enable_archive_date_meta'],
        'sanitize_callback' => 'sportsx_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'sportsx_options[enable_archive_date_meta]',
    array(
        'label'       => esc_html__( 'Show Date Meta', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);

$wp_customize->add_setting(
    'sportsx_options[select_archive_date]',
    array(
        'default'           => $sportsx_default['select_archive_date'],
        'sanitize_callback' => 'sportsx_sanitize_select',
    )
);
$wp_customize->add_control(
    'sportsx_options[select_archive_date]',
    array(
        'label'         => esc_html__( 'Date Meta Display Options', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'select',
        'choices'       => sportsx_date_meta(),
        'active_callback' => 'sportsx_is_archive_date_meta_enabled',

    )
);

$wp_customize->add_setting(
    'sportsx_options[archive_date_meta_title]',
    array(
        'default'           => $sportsx_default['archive_date_meta_title'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'sportsx_options[archive_date_meta_title]',
    array(
        'label'    => __( 'Date Text', 'sportsx' ),
        'section'  => 'archive_options',
        'type'     => 'text',
        'active_callback' => function ( $control ) {
            return (
                sportsx_is_archive_date_meta_enabled( $control )
                &&
                sportsx_archive_date_meta_title( $control )
            );
        },
    )
);

$wp_customize->add_setting(
    'sportsx_options[select_date_format]',
    array(
        'default'           => $sportsx_default['select_date_format'],
        'sanitize_callback' => 'sportsx_sanitize_select',
    )
);
$wp_customize->add_control(
    'sportsx_options[select_date_format]',
    array(
        'label'         => esc_html__( 'Select Date Format', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'select',
        'choices'  		=> sportsx_get_date_formats(),
        'active_callback' => 'sportsx_is_archive_date_meta_enabled',
    )
);

$wp_customize->add_setting(
    'sportsx_options[enable_category_meta]',
    array(
        'default'           => $sportsx_default['enable_category_meta'],
        'sanitize_callback' => 'sportsx_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'sportsx_options[enable_category_meta]',
    array(
        'label'       => esc_html__( 'Enable Category Meta', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);

$wp_customize->add_setting(
    'sportsx_options[number_of_category_to_display]',
    array(
        'default' => $sportsx_default['number_of_category_to_display'],
        'sanitize_callback' => 'absint',
    )
);
$wp_customize->add_control(
    'sportsx_options[number_of_category_to_display]',
    array(
        'label' => __('Number of Category', 'sportsx'),
        'section' => 'archive_options',
        'type' => 'number',
    )
);

$wp_customize->add_setting(
    'sportsx_options[archive_category_label]',
    array(
        'default'           => $sportsx_default['archive_category_label'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'sportsx_options[archive_category_label]',
    array(
        'label'    => __( 'Category Title', 'sportsx' ),
        'section'  => 'archive_options',
        'type'     => 'text',
        'active_callback' => 'sportsx_is_archive_category_meta_enabled',
    )
);

$wp_customize->add_setting(
    'sportsx_options[select_category_color]',
    array(
        'default'           => $sportsx_default['select_category_color'],
        'sanitize_callback' => 'sportsx_sanitize_select',
    )
);
$wp_customize->add_control(
    'sportsx_options[select_category_color]',
    array(
        'label'         => esc_html__( 'Select Category Color', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'select',
        'choices'  		=> sportsx_category_color(),
        'active_callback' => 'sportsx_is_archive_category_meta_enabled',

    )
);

$wp_customize->add_setting(
    'sportsx_options[enable_tag_meta]',
    array(
        'default'           => $sportsx_default['enable_tag_meta'],
        'sanitize_callback' => 'sportsx_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'sportsx_options[enable_tag_meta]',
    array(
        'label'       => esc_html__( 'Enable Tag Meta', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);

$wp_customize->add_setting(
    'sportsx_options[enable_comment_meta]',
    array(
        'default'           => $sportsx_default['enable_comment_meta'],
        'sanitize_callback' => 'sportsx_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'sportsx_options[enable_comment_meta]',
    array(
        'label'       => esc_html__( 'Enable Comment Meta', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);


$wp_customize->add_setting(
    'sportsx_options[enable_read_time_meta]',
    array(
        'default'           => $sportsx_default['enable_read_time_meta'],
        'sanitize_callback' => 'sportsx_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'sportsx_options[enable_read_time_meta]',
    array(
        'label'       => esc_html__( 'Enable Read Time', 'sportsx' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);
